@@ -3,9 +3,9 @@ package com.sun.tools.javap.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "18.0.1.1+2" },
-            { "jdk", "18.0.1.1" },
-            { "release", "18.0.1.1" },
+            { "full", "19.0.1+10" },
+            { "jdk", "19.0.1" },
+            { "release", "19.0.1" },
         };
     }
 }
