@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2013, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -40,15 +40,16 @@ class ZoneName {
 
     public static String toZid(String zid, Locale locale) {
         String mzone = zidToMzone.get(zid);
-        if (mzone == null && aliases.containsKey(zid)) {
-            zid = aliases.get(zid);
-            mzone = zidToMzone.get(zid);
+        if (mzone == null) {
+            String alias = aliases.get(zid);
+            if (alias != null) {
+                zid = alias;
+                mzone = zidToMzone.get(zid);
+            }
         }
         if (mzone != null) {
             Map<String, String> map = mzoneToZidL.get(mzone);
-            if (map != null && map.containsKey(locale.getCountry())) {
-                zid = map.get(locale.getCountry());
-            } else {
+            if (map == null || ((zid = map.get(locale.getCountry())) == null)) {
                 zid = mzoneToZid.get(mzone);
             }
         }
@@ -56,10 +57,7 @@ class ZoneName {
     }
 
     public static String toZid(String zid) {
-        if (aliases.containsKey(zid)) {
-            return aliases.get(zid);
-        }
-        return zid;
+        return aliases.getOrDefault(zid, zid);
     }
 
     private static final String[] zidMap = new String[] {
@@ -88,7 +86,7 @@ class ZoneName {
         "Africa/Gaborone", "Africa_Central", "Africa/Maputo",
         "Africa/Harare", "Africa_Central", "Africa/Maputo",
         "Africa/Johannesburg", "Africa_Southern", "Africa/Johannesburg",
-        "Africa/Juba", "Africa_Eastern", "Africa/Nairobi",
+        "Africa/Juba", "Africa_Central", "Africa/Maputo",
         "Africa/Kampala", "Africa_Eastern", "Africa/Nairobi",
         "Africa/Khartoum", "Africa_Central", "Africa/Maputo",
         "Africa/Kigali", "Africa_Central", "Africa/Maputo",
@@ -164,7 +162,7 @@ class ZoneName {
         "America/Cuiaba", "Amazon", "America/Manaus",
         "America/Curacao", "Atlantic", "America/Halifax",
         "America/Danmarkshavn", "GMT", "Atlantic/Reykjavik",
-        "America/Dawson", "America_Mountain", "America/Denver",
+        "America/Dawson", "Yukon", "America/Whitehorse",
         "America/Dawson_Creek", "America_Mountain", "America/Denver",
         "America/Denver", "America_Mountain", "America/Denver",
         "America/Detroit", "America_Eastern", "America/New_York",
@@ -277,7 +275,7 @@ class ZoneName {
         "America/Tortola", "Atlantic", "America/Halifax",
         "America/Vancouver", "America_Pacific", "America/Los_Angeles",
         "America/Virgin", "Atlantic", "America/Halifax",
-        "America/Whitehorse", "America_Mountain", "America/Denver",
+        "America/Whitehorse", "Yukon", "America/Whitehorse",
         "America/Winnipeg", "America_Central", "America/Chicago",
         "America/Yakutat", "Alaska", "America/Juneau",
         "America/Yellowknife", "America_Mountain", "America/Denver",
@@ -435,7 +433,7 @@ class ZoneName {
         "Canada/Newfoundland", "Newfoundland", "America/St_Johns",
         "Canada/Pacific", "America_Pacific", "America/Los_Angeles",
         "Canada/Saskatchewan", "America_Central", "America/Chicago",
-        "Canada/Yukon", "America_Mountain", "America/Denver",
+        "Canada/Yukon", "Yukon", "America/Whitehorse",
         "Chile/Continental", "Chile", "America/Santiago",
         "Chile/EasterIsland", "Easter", "Pacific/Easter",
         "Cuba", "Cuba", "America/Havana",
@@ -555,6 +553,7 @@ class ZoneName {
         "Pacific/Guam", "Chamorro", "Pacific/Saipan",
         "Pacific/Honolulu", "Hawaii_Aleutian", "Pacific/Honolulu",
         "Pacific/Johnston", "Hawaii_Aleutian", "Pacific/Honolulu",
+        "Pacific/Kanton", "Phoenix_Islands", "Pacific/Enderbury",
         "Pacific/Kiritimati", "Line_Islands", "Pacific/Kiritimati",
         "Pacific/Kosrae", "Kosrae", "Pacific/Kosrae",
         "Pacific/Kwajalein", "Marshall_Islands", "Pacific/Majuro",
@@ -775,6 +774,7 @@ class ZoneName {
         "SystemV/YST9YDT", "America/Anchorage",
 
         // From tzdb
+        "Africa/Accra", "Africa/Abidjan",
         "Africa/Addis_Ababa", "Africa/Nairobi",
         "Africa/Asmara", "Africa/Nairobi",
         "Africa/Asmera", "Africa/Nairobi",
@@ -809,49 +809,59 @@ class ZoneName {
         "Africa/Ouagadougou", "Africa/Abidjan",
         "Africa/Porto-Novo", "Africa/Lagos",
         "Africa/Timbuktu", "Africa/Abidjan",
-        "America/Anguilla", "America/Port_of_Spain",
-        "America/Antigua", "America/Port_of_Spain",
+        "America/Anguilla", "America/Puerto_Rico",
+        "America/Antigua", "America/Puerto_Rico",
         "America/Argentina/ComodRivadavia", "America/Argentina/Catamarca",
-        "America/Aruba", "America/Curacao",
+        "America/Aruba", "America/Puerto_Rico",
+        "America/Atikokan", "America/Panama",
         "America/Atka", "America/Adak",
+        "America/Blanc-Sablon", "America/Puerto_Rico",
         "America/Buenos_Aires", "America/Argentina/Buenos_Aires",
         "America/Catamarca", "America/Argentina/Catamarca",
         "America/Cayman", "America/Panama",
-        "America/Coral_Harbour", "America/Atikokan",
+        "America/Coral_Harbour", "America/Panama",
         "America/Cordoba", "America/Argentina/Cordoba",
-        "America/Dominica", "America/Port_of_Spain",
+        "America/Creston", "America/Phoenix",
+        "America/Curacao", "America/Puerto_Rico",
+        "America/Dominica", "America/Puerto_Rico",
         "America/Ensenada", "America/Tijuana",
         "America/Fort_Wayne", "America/Indiana/Indianapolis",
         "America/Godthab", "America/Nuuk",
-        "America/Grenada", "America/Port_of_Spain",
-        "America/Guadeloupe", "America/Port_of_Spain",
+        "America/Grenada", "America/Puerto_Rico",
+        "America/Guadeloupe", "America/Puerto_Rico",
         "America/Indianapolis", "America/Indiana/Indianapolis",
         "America/Jujuy", "America/Argentina/Jujuy",
         "America/Knox_IN", "America/Indiana/Knox",
-        "America/Kralendijk", "America/Curacao",
+        "America/Kralendijk", "America/Puerto_Rico",
         "America/Louisville", "America/Kentucky/Louisville",
-        "America/Lower_Princes", "America/Curacao",
-        "America/Marigot", "America/Port_of_Spain",
+        "America/Lower_Princes", "America/Puerto_Rico",
+        "America/Marigot", "America/Puerto_Rico",
         "America/Mendoza", "America/Argentina/Mendoza",
         "America/Montreal", "America/Toronto",
-        "America/Montserrat", "America/Port_of_Spain",
+        "America/Montserrat", "America/Puerto_Rico",
+        "America/Nassau", "America/Toronto",
+        "America/Port_of_Spain", "America/Puerto_Rico",
         "America/Porto_Acre", "America/Rio_Branco",
         "America/Rosario", "America/Argentina/Cordoba",
         "America/Santa_Isabel", "America/Tijuana",
         "America/Shiprock", "America/Denver",
-        "America/St_Barthelemy", "America/Port_of_Spain",
-        "America/St_Kitts", "America/Port_of_Spain",
-        "America/St_Lucia", "America/Port_of_Spain",
-        "America/St_Thomas", "America/Port_of_Spain",
-        "America/St_Vincent", "America/Port_of_Spain",
-        "America/Tortola", "America/Port_of_Spain",
-        "America/Virgin", "America/Port_of_Spain",
+        "America/St_Barthelemy", "America/Puerto_Rico",
+        "America/St_Kitts", "America/Puerto_Rico",
+        "America/St_Lucia", "America/Puerto_Rico",
+        "America/St_Thomas", "America/Puerto_Rico",
+        "America/St_Vincent", "America/Puerto_Rico",
+        "America/Tortola", "America/Puerto_Rico",
+        "America/Virgin", "America/Puerto_Rico",
+        "Antarctica/DumontDUrville", "Pacific/Port_Moresby",
         "Antarctica/McMurdo", "Pacific/Auckland",
         "Antarctica/South_Pole", "Pacific/Auckland",
-        "Arctic/Longyearbyen", "Europe/Oslo",
+        "Antarctica/Syowa", "Asia/Riyadh",
+        "Antarctica/Vostok", "Asia/Urumqi",
+        "Arctic/Longyearbyen", "Europe/Berlin",
         "Asia/Aden", "Asia/Riyadh",
         "Asia/Ashkhabad", "Asia/Ashgabat",
         "Asia/Bahrain", "Asia/Qatar",
+        "Asia/Brunei", "Asia/Kuching",
         "Asia/Calcutta", "Asia/Kolkata",
         "Asia/Chongqing", "Asia/Shanghai",
         "Asia/Chungking", "Asia/Shanghai",
@@ -860,6 +870,7 @@ class ZoneName {
         "Asia/Istanbul", "Europe/Istanbul",
         "Asia/Kashgar", "Asia/Urumqi",
         "Asia/Katmandu", "Asia/Kathmandu",
+        "Asia/Kuala_Lumpur", "Asia/Singapore",
         "Asia/Kuwait", "Asia/Riyadh",
         "Asia/Macao", "Asia/Macau",
         "Asia/Muscat", "Asia/Dubai",
@@ -872,7 +883,8 @@ class ZoneName {
         "Asia/Ulan_Bator", "Asia/Ulaanbaatar",
         "Asia/Vientiane", "Asia/Bangkok",
         "Atlantic/Faeroe", "Atlantic/Faroe",
-        "Atlantic/Jan_Mayen", "Europe/Oslo",
+        "Atlantic/Jan_Mayen", "Europe/Berlin",
+        "Atlantic/Reykjavik", "Africa/Abidjan",
         "Atlantic/St_Helena", "Africa/Abidjan",
         "Australia/ACT", "Australia/Sydney",
         "Australia/Canberra", "Australia/Sydney",
@@ -910,19 +922,26 @@ class ZoneName {
         "Etc/UCT", "Etc/UTC",
         "Etc/Universal", "Etc/UTC",
         "Etc/Zulu", "Etc/UTC",
+        "Europe/Amsterdam", "Europe/Brussels",
         "Europe/Belfast", "Europe/London",
         "Europe/Bratislava", "Europe/Prague",
         "Europe/Busingen", "Europe/Zurich",
+        "Europe/Copenhagen", "Europe/Berlin",
         "Europe/Guernsey", "Europe/London",
         "Europe/Isle_of_Man", "Europe/London",
         "Europe/Jersey", "Europe/London",
+        "Europe/Kiev", "Europe/Kyiv",
         "Europe/Ljubljana", "Europe/Belgrade",
+        "Europe/Luxembourg", "Europe/Brussels",
         "Europe/Mariehamn", "Europe/Helsinki",
+        "Europe/Monaco", "Europe/Paris",
         "Europe/Nicosia", "Asia/Nicosia",
+        "Europe/Oslo", "Europe/Berlin",
         "Europe/Podgorica", "Europe/Belgrade",
         "Europe/San_Marino", "Europe/Rome",
         "Europe/Sarajevo", "Europe/Belgrade",
         "Europe/Skopje", "Europe/Belgrade",
+        "Europe/Stockholm", "Europe/Berlin",
         "Europe/Tiraspol", "Europe/Chisinau",
         "Europe/Vaduz", "Europe/Zurich",
         "Europe/Vatican", "Europe/Rome",
@@ -935,10 +954,15 @@ class ZoneName {
         "GMT0", "Etc/GMT",
         "Greenwich", "Etc/GMT",
         "Hongkong", "Asia/Hong_Kong",
-        "Iceland", "Atlantic/Reykjavik",
+        "Iceland", "Africa/Abidjan",
         "Indian/Antananarivo", "Africa/Nairobi",
+        "Indian/Christmas", "Asia/Bangkok",
+        "Indian/Cocos", "Asia/Yangon",
         "Indian/Comoro", "Africa/Nairobi",
+        "Indian/Kerguelen", "Indian/Maldives",
+        "Indian/Mahe", "Asia/Dubai",
         "Indian/Mayotte", "Africa/Nairobi",
+        "Indian/Reunion", "Asia/Dubai",
         "Iran", "Asia/Tehran",
         "Israel", "Asia/Jerusalem",
         "Jamaica", "America/Jamaica",
@@ -955,13 +979,20 @@ class ZoneName {
         "NZ-CHAT", "Pacific/Chatham",
         "Navajo", "America/Denver",
         "PRC", "Asia/Shanghai",
+        "Pacific/Chuuk", "Pacific/Port_Moresby",
+        "Pacific/Enderbury", "Pacific/Kanton",
+        "Pacific/Funafuti", "Pacific/Tarawa",
         "Pacific/Johnston", "Pacific/Honolulu",
+        "Pacific/Majuro", "Pacific/Tarawa",
         "Pacific/Midway", "Pacific/Pago_Pago",
-        "Pacific/Ponape", "Pacific/Pohnpei",
+        "Pacific/Pohnpei", "Pacific/Guadalcanal",
+        "Pacific/Ponape", "Pacific/Guadalcanal",
         "Pacific/Saipan", "Pacific/Guam",
         "Pacific/Samoa", "Pacific/Pago_Pago",
-        "Pacific/Truk", "Pacific/Chuuk",
-        "Pacific/Yap", "Pacific/Chuuk",
+        "Pacific/Truk", "Pacific/Port_Moresby",
+        "Pacific/Wake", "Pacific/Tarawa",
+        "Pacific/Wallis", "Pacific/Tarawa",
+        "Pacific/Yap", "Pacific/Port_Moresby",
         "Poland", "Europe/Warsaw",
         "Portugal", "Europe/Lisbon",
         "ROC", "Asia/Taipei",
