@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2016, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -63,6 +63,7 @@ import jdk.internal.net.http.common.Log;
 import jdk.internal.net.http.common.Logger;
 import jdk.internal.net.http.common.MinimalFuture;
 import jdk.internal.net.http.common.Utils;
+import jdk.internal.net.http.HttpClientImpl.DelegatingExecutor;
 import static java.nio.charset.StandardCharsets.UTF_8;
 
 public class ResponseSubscribers {
@@ -77,7 +78,7 @@ public class ResponseSubscribers {
      * might be called and might block before the last bit is
      * received (for instance, if a mapping subscriber is used with
      * a mapper function that maps an InputStream to a GZIPInputStream,
-     * as the the constructor of GZIPInputStream calls read()).
+     * as the constructor of GZIPInputStream calls read()).
      * @param <T> The response type.
      */
     public interface TrustedSubscriber<T> extends BodySubscriber<T> {
@@ -174,6 +175,7 @@ public class ResponseSubscribers {
 
         private final Path file;
         private final OpenOption[] options;
+        @SuppressWarnings("removal")
         private final AccessControlContext acc;
         private final FilePermission[] filePermissions;
         private final boolean isDefaultFS;
@@ -196,6 +198,7 @@ public class ResponseSubscribers {
          */
         public static PathSubscriber create(Path file,
                                             List<OpenOption> options) {
+            @SuppressWarnings("removal")
             SecurityManager sm = System.getSecurityManager();
             FilePermission filePermission = null;
             if (sm != null) {
@@ -210,6 +213,7 @@ public class ResponseSubscribers {
             }
 
             assert filePermission == null || filePermission.getActions().equals("write");
+            @SuppressWarnings("removal")
             AccessControlContext acc = sm != null ? AccessController.getContext() : null;
             return new PathSubscriber(file, options, acc, filePermission);
         }
@@ -217,7 +221,7 @@ public class ResponseSubscribers {
         // pp so handler implementations in the same package can construct
         /*package-private*/ PathSubscriber(Path file,
                                            List<OpenOption> options,
-                                           AccessControlContext acc,
+                                           @SuppressWarnings("removal") AccessControlContext acc,
                                            FilePermission... filePermissions) {
             this.file = file;
             this.options = options.stream().toArray(OpenOption[]::new);
@@ -236,6 +240,7 @@ public class ResponseSubscribers {
             }
         }
 
+        @SuppressWarnings("removal")
         @Override
         public void onSubscribe(Flow.Subscription subscription) {
             Objects.requireNonNull(subscription);
@@ -303,6 +308,7 @@ public class ResponseSubscribers {
             return result;
         }
 
+        @SuppressWarnings("removal")
         private void close() {
             if (acc == null) {
                 Utils.close(out);
@@ -357,7 +363,7 @@ public class ResponseSubscribers {
             result.completeExceptionally(throwable);
         }
 
-        static private byte[] join(List<ByteBuffer> bytes) {
+        private static byte[] join(List<ByteBuffer> bytes) {
             int size = Utils.remaining(bytes, Integer.MAX_VALUE);
             byte[] res = new byte[size];
             int from = 0;
@@ -391,7 +397,7 @@ public class ResponseSubscribers {
     public static class HttpResponseInputStream extends InputStream
         implements TrustedSubscriber<InputStream>
     {
-        final static int MAX_BUFFERS_IN_QUEUE = 1;  // lock-step with the producer
+        static final int MAX_BUFFERS_IN_QUEUE = 1;  // lock-step with the producer
 
         // An immutable ByteBuffer sentinel to mark that the last byte was received.
         private static final ByteBuffer LAST_BUFFER = ByteBuffer.wrap(new byte[0]);
@@ -877,7 +883,7 @@ public class ResponseSubscribers {
         // A subscription that wraps an upstream subscription and
         // holds a reference to a subscriber. The subscriber reference
         // is cleared when the subscription is cancelled
-        final static class SubscriptionRef implements Flow.Subscription {
+        static final class SubscriptionRef implements Flow.Subscription {
             final Flow.Subscription subscription;
             final SubscriberRef subscriberRef;
             SubscriptionRef(Flow.Subscription subscription,
@@ -1081,7 +1087,7 @@ public class ResponseSubscribers {
      * Invokes bs::getBody using the provided executor.
      * If invoking bs::getBody requires an executor, and the given executor
      * is a {@link HttpClientImpl.DelegatingExecutor}, then the executor's
-     * delegate is used. If an error occurs anywhere then the given {code cf}
+     * delegate is used. If an error occurs anywhere then the given {@code cf}
      * is completed exceptionally (this method does not throw).
      * @param e   The executor that should be used to call bs::getBody
      * @param bs  The BodySubscriber
@@ -1136,8 +1142,8 @@ public class ResponseSubscribers {
             assert cf != null;
 
             if (TrustedSubscriber.needsExecutor(bs)) {
-                e = (e instanceof HttpClientImpl.DelegatingExecutor)
-                        ? ((HttpClientImpl.DelegatingExecutor) e).delegate() : e;
+                e = (e instanceof DelegatingExecutor exec)
+                        ? exec::ensureExecutedAsync : e;
             }
 
             e.execute(() -> {
@@ -1150,12 +1156,14 @@ public class ResponseSubscribers {
                         }
                     });
                 } catch (Throwable t) {
+                    // the errorHandler will complete the CF
                     errorHandler.accept(t);
                 }
             });
             return cf;
 
         } catch (Throwable t) {
+            // the errorHandler will complete the CF
             errorHandler.accept(t);
         }
         return cf;
