@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -66,27 +66,43 @@ import java.util.ListResourceBundle;
 public class FormatData_en_HK extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
-        final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
-               "EEEE, d MMMM, y G",
-               "d MMMM, y G",
-               "d MMM, y G",
-               "d/M/yy GGGGG",
-            };
-        final String[] metaValue_buddhist_DatePatterns = new String[] {
-               "EEEE, d MMMM, y GGGG",
-               "d MMMM, y GGGG",
-               "d MMM, y GGGG",
-               "d/M/yy G",
-            };
+        final String[] metaValue_java_time_generic_DatePatterns = new String[] {
+            "EEEE, d MMMM, y G",
+            "d MMMM, y G",
+            "d MMM, y G",
+            "d/M/yy GGGGG",
+        };
+        final String[] metaValue_generic_DatePatterns = new String[] {
+            "EEEE, d MMMM, y GGGG",
+            "d MMMM, y GGGG",
+            "d MMM, y GGGG",
+            "d/M/yy G",
+        };
+        final String metaValue_generic_DateFormatItem_MMMMEd = "E, d MMMM";
+        final String metaValue_generic_DateFormatItem_yMd = "d/M/y";
         final Object[][] data = new Object[][] {
-            { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "generic.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
+            { "generic.DatePatterns", metaValue_generic_DatePatterns },
+            { "islamic-civil.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
+            { "islamic-umalqura.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
+            { "japanese.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
+            { "java.time.japanese.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "islamic.DatePatterns", metaValue_generic_DatePatterns },
+            { "generic.DateFormatItem.yyyyMMMEd", "E, d MMM, y G" },
+            { "buddhist.DatePatterns", metaValue_generic_DatePatterns },
+            { "islamic-umalqura.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
+            { "roc.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
+            { "roc.DatePatterns", metaValue_generic_DatePatterns },
+            { "DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
+            { "japanese.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
+            { "generic.DateFormatItem.yyyyMd", "d/M/y GGGGG" },
+            { "islamic-civil.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
+            { "DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
+            { "generic.DateFormatItem.yyyyMEd", "E, d/M/y GGGGG" },
+            { "java.time.buddhist.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "java.time.roc.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "generic.DateFormatItem.yyyyMMMd", "d MMM, y G" },
+            { "java.time.islamic.DatePatterns", metaValue_java_time_generic_DatePatterns },
             { "DatePatterns",
                 new String[] {
                     "EEEE, d MMMM y",
@@ -95,6 +111,14 @@ public class FormatData_en_HK extends ListResourceBundle {
                     "d/M/y",
                 }
             },
+            { "java.time.generic.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "generic.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
+            { "islamic.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
+            { "japanese.DatePatterns", metaValue_generic_DatePatterns },
+            { "buddhist.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
+            { "roc.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
+            { "buddhist.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
+            { "islamic.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
         };
         return data;
     }
