@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -66,26 +66,27 @@ import java.util.ListResourceBundle;
 public class FormatData_fr_BE extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
-        final String[] metaValue_buddhist_TimePatterns = new String[] {
-               "H 'h' mm 'min' ss 's' zzzz",
-               "",
-               "",
-               "",
-            };
-        final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
-               "EEEE d MMMM y G",
-               "d MMMM y G",
-               "d MMM y G",
-               "d/MM/yy GGGGG",
-            };
-        final String[] metaValue_buddhist_DatePatterns = new String[] {
-               "EEEE d MMMM y GGGG",
-               "d MMMM y GGGG",
-               "d MMM y GGGG",
-               "d/MM/yy G",
-            };
+        final String[] metaValue_generic_TimePatterns = new String[] {
+            "H 'h' mm 'min' ss 's' zzzz",
+            "",
+            "",
+            "",
+        };
+        final String[] metaValue_java_time_generic_DatePatterns = new String[] {
+            "EEEE d MMMM y G",
+            "d MMMM y G",
+            "d MMM y G",
+            "d/MM/yy GGGGG",
+        };
+        final String[] metaValue_generic_DatePatterns = new String[] {
+            "EEEE d MMMM y GGGG",
+            "d MMMM y GGGG",
+            "d MMM y GGGG",
+            "d/MM/yy G",
+        };
         final Object[][] data = new Object[][] {
-            { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "generic.DatePatterns", metaValue_generic_DatePatterns },
+            { "java.time.buddhist.DatePatterns", metaValue_java_time_generic_DatePatterns },
             { "java.time.roc.DatePatterns",
                 new String[] {
                     "",
@@ -94,7 +95,7 @@ public class FormatData_fr_BE extends ListResourceBundle {
                     "d/MM/yy GGGGG",
                 }
             },
-            { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "java.time.japanese.DatePatterns", metaValue_java_time_generic_DatePatterns },
             { "TimePatterns",
                 new String[] {
                     "H 'h' mm 'min' ss 's' zzzz",
@@ -103,8 +104,8 @@ public class FormatData_fr_BE extends ListResourceBundle {
                     "HH:mm",
                 }
             },
-            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "java.time.islamic.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "islamic.DatePatterns", metaValue_generic_DatePatterns },
             { "DatePatterns",
                 new String[] {
                     "EEEE d MMMM y",
@@ -113,12 +114,14 @@ public class FormatData_fr_BE extends ListResourceBundle {
                     "d/MM/yy",
                 }
             },
-            { "islamic.TimePatterns", metaValue_buddhist_TimePatterns },
-            { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "buddhist.TimePatterns", metaValue_buddhist_TimePatterns },
-            { "japanese.TimePatterns", metaValue_buddhist_TimePatterns },
-            { "roc.TimePatterns", metaValue_buddhist_TimePatterns },
+            { "java.time.generic.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "islamic.TimePatterns", metaValue_generic_TimePatterns },
+            { "generic.TimePatterns", metaValue_generic_TimePatterns },
+            { "japanese.DatePatterns", metaValue_generic_DatePatterns },
+            { "buddhist.DatePatterns", metaValue_generic_DatePatterns },
+            { "buddhist.TimePatterns", metaValue_generic_TimePatterns },
+            { "japanese.TimePatterns", metaValue_generic_TimePatterns },
+            { "roc.TimePatterns", metaValue_generic_TimePatterns },
             { "roc.DatePatterns",
                 new String[] {
                     "",
