@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -272,7 +268,7 @@ public class CurrencyNames_en extends OpenListResourceBundle {
             { "pen", "Peruvian Sol" },
             { "pes", "Peruvian Sol (1863\u20131965)" },
             { "pgk", "Papua New Guinean Kina" },
-            { "php", "Philippine Piso" },
+            { "php", "Philippine Peso" },
             { "pkr", "Pakistani Rupee" },
             { "pln", "Polish Zloty" },
             { "plz", "Polish Zloty (1950\u20131995)" },
@@ -297,6 +293,7 @@ public class CurrencyNames_en extends OpenListResourceBundle {
             { "shp", "St. Helena Pound" },
             { "sit", "Slovenian Tolar" },
             { "skk", "Slovak Koruna" },
+            { "sle", "Sierra Leonean New Leone" },
             { "sll", "Sierra Leonean Leone" },
             { "sos", "Somali Shilling" },
             { "srd", "Surinamese Dollar" },
@@ -334,6 +331,7 @@ public class CurrencyNames_en extends OpenListResourceBundle {
             { "uyw", "Uruguayan Nominal Wage Index Unit" },
             { "uzs", "Uzbekistani Som" },
             { "veb", "Venezuelan Bol\u00edvar (1871\u20132008)" },
+            { "ved", "Bol\u00edvar Soberano" },
             { "vef", "Venezuelan Bol\u00edvar (2008\u20132018)" },
             { "ves", "Venezuelan Bol\u00edvar" },
             { "vnd", "Vietnamese Dong" },
