@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -138,6 +138,7 @@ public class CurrencyNames_kok extends OpenListResourceBundle {
             { "LBP", "LBP" },
             { "LKR", "LKR" },
             { "LRD", "LRD" },
+            { "LSL", "LSL" },
             { "LYD", "LYD" },
             { "MAD", "MAD" },
             { "MDL", "MDL" },
@@ -284,6 +285,7 @@ public class CurrencyNames_kok extends OpenListResourceBundle {
             { "lbp", "\u0932\u093f\u092c\u093e\u0928\u0947\u0938 \u092a\u093e\u0935\u0902\u0921" },
             { "lkr", "\u0936\u094d\u0930\u0940 \u0932\u0902\u0915\u093e \u0930\u0941\u092a\u092f\u093e" },
             { "lrd", "\u0932\u093e\u092f\u092c\u0947\u0930\u093f\u092f\u0928 \u0921\u0949\u0932\u0930" },
+            { "lsl", "\u0932\u093f\u0938\u094b\u0925\u094b \u0932\u094b\u091f\u093f" },
             { "lyd", "\u0932\u0940\u092c\u093f\u092f\u093e\u0928 \u0921\u093f\u0928\u093e\u0930" },
             { "mad", "\u092e\u094b\u0930\u0915\u094d\u0915\u0928 \u0926\u093f\u0930\u0939\u092e" },
             { "mdl", "\u092e\u094b\u0932\u094d\u0926\u094b\u0935\u093e\u0928 \u0932\u093f\u092f\u0942" },
