@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -242,7 +238,7 @@ public class CurrencyNames_pl extends OpenListResourceBundle {
             { "azn", "manat azerski" },
             { "bad", "dinar Bo\u015bni i Hercegowiny" },
             { "bam", "marka zamienna Bo\u015bni i Hercegowiny" },
-            { "bbd", "dolar Barbadosu" },
+            { "bbd", "dolar barbadoski" },
             { "bdt", "taka bengalska" },
             { "bec", "frank belgijski (zamienny)" },
             { "bef", "frank belgijski" },
@@ -352,7 +348,7 @@ public class CurrencyNames_pl extends OpenListResourceBundle {
             { "lbp", "funt liba\u0144ski" },
             { "lkr", "rupia lankijska" },
             { "lrd", "dolar liberyjski" },
-            { "lsl", "loti Lesoto" },
+            { "lsl", "loti lesotyjskie" },
             { "ltl", "lit litewski" },
             { "ltt", "talon litewski" },
             { "luf", "frank luksemburski" },
@@ -442,7 +438,7 @@ public class CurrencyNames_pl extends OpenListResourceBundle {
             { "tpe", "escudo timorskie" },
             { "trl", "lira turecka (1922\u20132005)" },
             { "try", "lira turecka" },
-            { "ttd", "dolar Trynidadu i Tobago" },
+            { "ttd", "dolar trynidadzki" },
             { "twd", "nowy dolar tajwa\u0144ski" },
             { "tzs", "szyling tanza\u0144ski" },
             { "uah", "hrywna ukrai\u0144ska" },
