@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -79,8 +75,8 @@ public class LocaleNames_pt_PT extends OpenListResourceBundle {
             { "Zsym", "s\u00edmbolos" },
             { "type.nu.greklow", "Numera\u00e7\u00e3o grega min\u00fascula" },
             { "pt_BR", "portugu\u00eas do Brasil" },
-            { "Zsye", "emoji" },
             { "key.cf", "Formato monet\u00e1rio" },
+            { "ccp", "changma" },
             { "egy", "eg\u00edpcio cl\u00e1ssico" },
             { "bax", "bamun" },
             { "raj", "rajastan\u00eas" },
@@ -89,6 +85,7 @@ public class LocaleNames_pt_PT extends OpenListResourceBundle {
             { "tem", "temne" },
             { "QO", "Oce\u00e2nia Insular" },
             { "lez", "lezghiano" },
+            { "Aran", "nasta\u2019liq" },
             { "af", "african\u00eas" },
             { "type.ca.ethiopic", "Calend\u00e1rio et\u00edope" },
             { "bbj", "ghomala" },
@@ -125,19 +122,20 @@ public class LocaleNames_pt_PT extends OpenListResourceBundle {
             { "CC", "Ilhas dos Cocos (Keeling)" },
             { "type.cf.account", "Formato monet\u00e1rio contabil\u00edstico" },
             { "CD", "Congo-Kinshasa" },
+            { "st", "sesoto" },
             { "SV", "Salvador" },
             { "ars", "\u00e1rabe do N\u00e9gede" },
             { "CG", "Congo-Brazzaville" },
             { "SX", "S\u00e3o Martinho (Sint Maarten)" },
             { "CI", "C\u00f4te d\u2019Ivoire (Costa do Marfim)" },
             { "type.nu.hantfin", "Numera\u00e7\u00e3o financeira em chin\u00eas tradicional" },
-            { "SZ", "Essuat\u00edni" },
             { "co", "c\u00f3rsico" },
             { "Orya", "odia" },
             { "type.ms.ussystem", "Sistema de medida americano" },
             { "bua", "buriat" },
             { "cs", "checo" },
             { "te", metaValue_te },
+            { "TF", "Territ\u00f3rios Austrais Franceses" },
             { "cv", "chuvash" },
             { "tg", "tajique" },
             { "CW", "Cura\u00e7au" },
@@ -168,7 +166,6 @@ public class LocaleNames_pt_PT extends OpenListResourceBundle {
             { "es_419", "espanhol latino-americano" },
             { "039", "Europa do Sul" },
             { "pag", "l\u00edngua pangasinesa" },
-            { "type.d0.hwidth", "Meia largura" },
             { "UM", "Ilhas Menores Afastadas dos EUA" },
             { "type.ca.chinese", "Calend\u00e1rio chin\u00eas" },
             { "EA", "Ceuta e Melilha" },
@@ -176,12 +173,11 @@ public class LocaleNames_pt_PT extends OpenListResourceBundle {
             { "pam", "pampango" },
             { "type.nu.grek", "Numera\u00e7\u00e3o grega" },
             { "EE", "Est\u00f3nia" },
-            { "ee", "ewe" },
             { "type.lb.normal", "Estilo padr\u00e3o de quebra de linha" },
             { "EH", "Sara Ocidental" },
             { "UZ", "Usbequist\u00e3o" },
             { "uz", "usbeque" },
-            { "tzm", "tamazight do Atlas Central" },
+            { "tzm", "tamazigue do Atlas Central" },
             { "type.co.stroke", "Ordem por tra\u00e7os" },
             { "chk", "chuqu\u00eas" },
             { "chn", "jarg\u00e3o chinook" },
@@ -201,15 +197,14 @@ public class LocaleNames_pt_PT extends OpenListResourceBundle {
             { "VN", "Vietname" },
             { "shu", "\u00e1rabe do Chade" },
             { "fon", "fon" },
-            { "FK", "Ilhas Malvinas (Falkland)" },
-            { "FO", "Ilhas Faro\u00e9" },
+            { "FK", "Ilhas Falkland" },
+            { "key.va", "Variante de regi\u00e3o" },
             { "type.m0.bgn", "Translitera\u00e7\u00e3o BGN" },
             { "non", "n\u00f3rdico antigo" },
             { "%%AREVMDA", "arm\u00e9nio ocidental" },
             { "type.co.traditional", "Ordem tradicional" },
             { "fy", "fr\u00edsico ocidental" },
             { "type.nu.finance", "Algarismos financeiros" },
-            { "root", "root" },
             { "type.ca.indian", "Calend\u00e1rio nacional indiano" },
             { "wo", "u\u00f3lofe" },
             { "grc", "grego cl\u00e1ssico" },
@@ -218,15 +213,16 @@ public class LocaleNames_pt_PT extends OpenListResourceBundle {
             { "GG", "Guernesey" },
             { "Tale", "tai le" },
             { "GL", "Gronel\u00e2ndia" },
+            { "XA", "Pseudoacentos" },
             { "type.ca.ethiopic-amete-alem", "Calend\u00e1rio Et\u00edope Amete Alem" },
             { "type.nu.hans", "Numera\u00e7\u00e3o em chin\u00eas simplificado" },
             { "GU", "Guame" },
             { "type.nu.hant", "Numera\u00e7\u00e3o em chin\u00eas tradicional" },
             { "xh", "xosa" },
+            { "rhg", "rohingya" },
             { "type.nu.romanlow", "Numera\u00e7\u00e3o romana min\u00fascula" },
             { "Zxxx", "n\u00e3o escrito" },
             { "ha", "ha\u00fa\u00e7a" },
-            { "ckb", "sorani curdo" },
             { "hi", "hindi" },
             { "de_AT", "alem\u00e3o austr\u00edaco" },
             { "moh", "mohawk" },
@@ -286,7 +282,6 @@ public class LocaleNames_pt_PT extends OpenListResourceBundle {
             { "type.nu.arabext", "Algarismos indo-ar\u00e1bicos expandidos" },
             { "type.nu.fullwide", "Algarismos de largura completa" },
             { "MC", "M\u00f3naco" },
-            { "MD", "Mold\u00e1via" },
             { "MG", "Madag\u00e1scar" },
             { "type.co.ducet", "Ordena\u00e7\u00e3o unicode predefinida" },
             { "lrc", "luri do norte" },
@@ -319,11 +314,11 @@ public class LocaleNames_pt_PT extends OpenListResourceBundle {
             { "type.nu.tamldec", "Algarismos de t\u00e2mil" },
             { "type.nu.armn", "Numera\u00e7\u00e3o arm\u00e9nia" },
             { "krc", "carachaio-b\u00e1lcaro" },
-            { "or", "oriya" },
             { "os", "oss\u00e9tico" },
             { "crs", "franc\u00eas crioulo seselwa" },
             { "efi", "efik" },
             { "kbd", "cabardiano" },
+            { "mfe", "crioulo mauriciano" },
             { "type.ca.islamic-civil", "Calend\u00e1rio isl\u00e2mico (civil)" },
             { "en_GB", "ingl\u00eas brit\u00e2nico" },
             { "PL", "Pol\u00f3nia" },
