@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -280,7 +276,6 @@ public class LocaleNames_yue_Hans extends OpenListResourceBundle {
             { "pcd", "\u5e87\u5361\u5e95\u6587" },
             { "tkl", "\u6258\u514b\u52b3\u6587" },
             { "grb", "\u683c\u5217\u535a\u6587" },
-            { "root", "\u6839\u8bed\u8a00" },
             { "type.ca.indian", "\u5370\u5ea6\u56fd\u5386" },
             { "rgn", "\u7f57\u9a6c\u683c\u8bfa\u91cc\u6587" },
             { "grc", "\u53e4\u5e0c\u814a\u6587" },
@@ -309,6 +304,7 @@ public class LocaleNames_yue_Hans extends OpenListResourceBundle {
             { "GU", "\u5173\u5c9b" },
             { "pdc", "\u5bbe\u5915\u6cd5\u5c3c\u4e9a\u5fb7\u6587" },
             { "GW", "\u51e0\u5185\u4e9a\u6bd4\u7d22" },
+            { "rhg", "\u7f57\u5174\u4e9a\u6587" },
             { "tli", "\u7279\u6797\u57fa\u7279\u6587" },
             { "tlh", "\u514b\u6797\u8d21\u6587" },
             { "Talu", "\u897f\u53cc\u7248\u7eb3\u65b0\u50a3\u6587" },
@@ -688,6 +684,7 @@ public class LocaleNames_yue_Hans extends OpenListResourceBundle {
             { "was", "\u74e6\u7ecd\u6587" },
             { "XA", "\u4f2a\u53e3\u97f3" },
             { "war", "\u74e6\u745e\u6587" },
+            { "XB", "\u4f2a Bidi" },
             { "awa", "\u963f\u74e6\u6587" },
             { "061", "\u73bb\u91cc\u5c3c\u897f\u4e9a" },
             { "XK", "\u79d1\u7d22\u6c83" },
@@ -1341,6 +1338,7 @@ public class LocaleNames_yue_Hans extends OpenListResourceBundle {
             { "inh", "\u5370\u53e4\u4ec0\u6587" },
             { "krj", "\u57fa\u90a3\u6765\u963f\u6587" },
             { "kri", "\u585e\u62c9\u5229\u6602\u514b\u91cc\u5965\u5c14\u6587" },
+            { "fa_AF", "\u8fbe\u91cc\u6587" },
             { "krl", "\u5361\u7d2f\u5229\u963f\u6587" },
             { "efi", "\u57c3\u83f2\u514b\u6587" },
             { "tcy", "\u56fe\u5362\u6587" },
