@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -182,6 +178,14 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Casey = new String[] {
+               "Am St\u00e1isi\u00fan Casey",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Chile = new String[] {
                "Am Caighde\u00e1nach na Sile",
                "",
@@ -207,7 +211,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "",
             };
         final String[] Davis = new String[] {
-               "Am St\u00e1isi\u00fan Davis",
+               "Am Davis",
                "",
                "",
                "",
@@ -271,7 +275,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "",
             };
         final String[] Syowa = new String[] {
-               "Am St\u00e1isi\u00fan Syowa",
+               "Am Syowa",
                "",
                "",
                "",
@@ -286,6 +290,14 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "Am Thonga",
                "",
             };
+        final String[] Yukon = new String[] {
+               "Am Yukon",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Alaska = new String[] {
                "Am Caighde\u00e1nach Alasca",
                "",
@@ -327,7 +339,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "",
             };
         final String[] Brunei = new String[] {
-               "Am Br\u00fain\u00e9 Darasal\u00e1m",
+               "Am Bhr\u00fain\u00e9 Darasal\u00e1m",
                "",
                "",
                "",
@@ -367,7 +379,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "",
             };
         final String[] Mawson = new String[] {
-               "Am St\u00e1isi\u00fan Mawson",
+               "Am Mawson",
                "",
                "",
                "",
@@ -407,15 +419,15 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "",
             };
         final String[] Taipei = new String[] {
-               "Am Caighde\u00e1nach Thaipei",
+               "Am Caighde\u00e1nach Taipei",
                "",
-               "Am Samhraidh Thaipei",
+               "Am Samhraidh Taipei",
                "",
-               "Am Thaipei",
+               "Am Taipei",
                "",
             };
         final String[] Tuvalu = new String[] {
-               "Am Thuvalu",
+               "Am Th\u00faval\u00fa",
                "",
                "",
                "",
@@ -423,7 +435,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "",
             };
         final String[] Vostok = new String[] {
-               "Am St\u00e1isi\u00fan Vostok",
+               "Am Vostok",
                "",
                "",
                "",
@@ -431,7 +443,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "",
             };
         final String[] Wallis = new String[] {
-               "Am Vail\u00eds agus Fut\u00fana",
+               "Am Wallis agus Futuna",
                "",
                "",
                "",
@@ -487,7 +499,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "",
             };
         final String[] Gambier = new String[] {
-               "Am Ghambier",
+               "Am Gambier",
                "",
                "",
                "",
@@ -535,11 +547,11 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "",
             };
         final String[] Noronha = new String[] {
-               "Am Caighde\u00e1nach Fhernando de Noronha",
+               "Am Caighde\u00e1nach Fernando de Noronha",
                "",
-               "Am Samhraidh Fhernando de Noronha",
+               "Am Samhraidh Fernando de Noronha",
                "",
-               "Am Fhernando de Noronha",
+               "Am Fernando de Noronha",
                "",
             };
         final String[] Reunion = new String[] {
@@ -551,7 +563,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "",
             };
         final String[] Rothera = new String[] {
-               "Am St\u00e1isi\u00fan Rothera",
+               "Am Rothera",
                "",
                "",
                "",
@@ -559,7 +571,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "",
             };
         final String[] Solomon = new String[] {
-               "Am Oile\u00e1in Sholom\u00f3n",
+               "Am Oile\u00e1in Sholaimh",
                "",
                "",
                "",
@@ -679,7 +691,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "",
             };
         final String[] Pitcairn = new String[] {
-               "Am Oile\u00e1n Pitcairn",
+               "Am Pitcairn",
                "",
                "",
                "",
@@ -687,11 +699,11 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "",
             };
         final String[] Sakhalin = new String[] {
-               "Am Caighde\u00e1nach Shakhalin",
+               "Am Caighde\u00e1nach Shacail\u00edn",
                "",
-               "Am Samhraidh Shakhalin",
+               "Am Samhraidh Shacail\u00edn",
                "",
-               "Am Shakhalin",
+               "Am Shacail\u00edn",
                "",
             };
         final String[] Suriname = new String[] {
@@ -766,14 +778,6 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "Am Lord Howe",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "Am Oile\u00e1n Mhic Guaire",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "Am na nOile\u00e1n Marcasach",
                "",
@@ -983,7 +987,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "",
             };
         final String[] Africa_Central = new String[] {
-               "Am L\u00e1r na hAfraice",
+               "Am na hAfraice L\u00e1ir",
                "",
                "",
                "",
@@ -1007,7 +1011,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "",
             };
         final String[] DumontDUrville = new String[] {
-               "Am St\u00e1isi\u00fan Dumont-d\u2019Urville",
+               "Am Dumont-d\u2019Urville",
                "",
                "",
                "",
@@ -1047,7 +1051,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "",
             };
         final String[] Africa_Southern = new String[] {
-               "Am Caighde\u00e1nach na hAfraice Theas",
+               "Am na hAfraice Theas",
                "",
                "",
                "",
@@ -1055,19 +1059,19 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "",
             };
         final String[] America_Central = new String[] {
-               "Am Caighde\u00e1nach L\u00e1rnach",
+               "Am Caighde\u00e1nach L\u00e1rnach Mheirice\u00e1 Thuaidh",
                "",
-               "Am Samhraidh L\u00e1rnach",
+               "Am Samhraidh L\u00e1rnach Mheirice\u00e1 Thuaidh",
                "",
-               "Am L\u00e1rnach",
+               "Am L\u00e1rnach Mheirice\u00e1 Thuaidh",
                "",
             };
         final String[] America_Eastern = new String[] {
-               "Am Caighde\u00e1nach an Oirthir",
+               "Am Caighde\u00e1nach Oirthearach Mheirice\u00e1 Thuaidh",
                "",
-               "Am Samhraidh an Oirthir",
+               "Am Samhraidh Oirthearach Mheirice\u00e1 Thuaidh",
                "",
-               "Am an Oirthir",
+               "Am Oirthearach Mheirice\u00e1 Thuaidh",
                "",
             };
         final String[] America_Pacific = new String[] {
@@ -1079,7 +1083,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "AAC",
             };
         final String[] French_Southern = new String[] {
-               "Am Chr\u00edocha Francacha Deisceart an Domhain",
+               "Am Francach Dheisceart an Domhain agus an Antartaigh",
                "",
                "",
                "",
@@ -1119,11 +1123,11 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "",
             };
         final String[] America_Mountain = new String[] {
-               "Am Caighde\u00e1nach na Sl\u00e9ibhte",
+               "Am Caighde\u00e1nach Sl\u00e9ibhte Mheirice\u00e1 Thuaidh",
                "",
-               "Am Samhraidh na Sl\u00e9ibhte",
+               "Am Samhraidh Sl\u00e9ibhte Mheirice\u00e1 Thuaidh",
                "",
-               "Am na Sl\u00e9ibhte",
+               "Am Sl\u00e9ibhte Mheirice\u00e1 Thuaidh",
                "",
             };
         final String[] Marshall_Islands = new String[] {
@@ -1300,7 +1304,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Anadyr", Anadyr },
@@ -1450,7 +1454,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", Yukon },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1576,7 +1580,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
+            { "Antarctica/Casey", Casey },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1657,7 +1661,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "America/Paramaribo", Suriname },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1697,7 +1701,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1721,7 +1725,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "America/Indiana/Vincennes", America_Eastern },
             { "Antarctica/DumontDUrville", DumontDUrville },
             { "timezone.excity.Asia/Aden", "\u00c1idin" },
-            { "timezone.excity.Asia/Baku", "Baku" },
+            { "timezone.excity.Asia/Baku", "Baki" },
             { "timezone.excity.Asia/Dili", "Dili" },
             { "timezone.excity.Asia/Gaza", "Gaza" },
             { "timezone.excity.Asia/Hovd", "Hovd" },
@@ -1745,7 +1749,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
             { "timezone.excity.Africa/Juba", "Juba" },
-            { "timezone.excity.Africa/Lome", "Lome" },
+            { "timezone.excity.Africa/Lome", "Lom\u00e9" },
             { "timezone.excity.Asia/Almaty", "Almaty" },
             { "timezone.excity.Asia/Anadyr", "Anadyr" },
             { "timezone.excity.Asia/Aqtobe", "Aqtobe" },
@@ -1804,7 +1808,6 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Fiji", "Fids\u00ed" },
             { "timezone.excity.Pacific/Guam", "Guam" },
             { "timezone.excity.Pacific/Niue", "Niue" },
-            { "timezone.excity.Pacific/Wake", "Oile\u00e1n Wake" },
             { "timezone.excity.Africa/Bamako", "Bamako" },
             { "timezone.excity.Africa/Bangui", "Bangui" },
             { "timezone.excity.Africa/Banjul", "Banjul" },
@@ -1824,14 +1827,15 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "timezone.excity.America/Boise", "Boise" },
             { "timezone.excity.America/Jujuy", "Jujuy" },
             { "timezone.excity.America/Sitka", "Sitka" },
-            { "timezone.excity.America/Thule", "Thule" },
+            { "timezone.excity.America/Thule", "Inis Tuile" },
             { "timezone.excity.Asia/Ashgabat", "Ashgabat" },
             { "timezone.excity.Asia/Calcutta", "Calc\u00fata" },
             { "timezone.excity.Asia/Damascus", "an Damaisc" },
             { "timezone.excity.Asia/Dushanbe", "Dushanbe" },
             { "timezone.excity.Asia/Jayapura", "Jayapura" },
             { "timezone.excity.Asia/Khandyga", "Khandyga" },
-            { "timezone.excity.Asia/Makassar", "Makassar" },
+            { "timezone.excity.Asia/Makassar", "Macasar" },
+            { "timezone.excity.Asia/Qostanay", "Kostanay" },
             { "timezone.excity.Asia/Sakhalin", "Sakhalin" },
             { "timezone.excity.Asia/Shanghai", "Shang-hai" },
             { "timezone.excity.Asia/Tashkent", "Tashkent" },
@@ -1848,7 +1852,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Prague", "Pr\u00e1g" },
             { "timezone.excity.Europe/Samara", "Samara" },
             { "timezone.excity.Europe/Skopje", "Sc\u00f3ip\u00e9" },
-            { "timezone.excity.Europe/Tirane", "Tirane" },
+            { "timezone.excity.Europe/Tirane", "Tior\u00e1na" },
             { "timezone.excity.Europe/Vienna", "V\u00edn" },
             { "timezone.excity.Europe/Warsaw", "V\u00e1rs\u00e1" },
             { "timezone.excity.Europe/Zagreb", "S\u00e1grab" },
@@ -1871,15 +1875,12 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "timezone.excity.America/Bogota", "Bogat\u00e1" },
             { "timezone.excity.America/Cancun", "Canc\u00fan" },
             { "timezone.excity.America/Cayman", "Cayman" },
-            { "timezone.excity.America/Cuiaba", "Cuiab\u00e1" },
             { "timezone.excity.America/Dawson", "Dawson" },
             { "timezone.excity.America/Denver", "Denver" },
             { "timezone.excity.America/Guyana", "an Ghu\u00e1in" },
-            { "timezone.excity.America/Havana", "Hav\u00e1na" },
             { "timezone.excity.America/Inuvik", "Inuvik" },
             { "timezone.excity.America/Juneau", "Juneau" },
             { "timezone.excity.America/La_Paz", "La Paz" },
-            { "timezone.excity.America/Maceio", "Macei\u00f3" },
             { "timezone.excity.America/Manaus", "Manaus" },
             { "timezone.excity.America/Merida", "Merida" },
             { "timezone.excity.America/Nassau", "Nassau" },
@@ -1899,11 +1900,10 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Andorra", "And\u00f3ra" },
             { "timezone.excity.Europe/Saratov", "Saratov" },
             { "timezone.excity.Europe/Tallinn", "Taillinn" },
-            { "timezone.excity.Europe/Vatican", "Cathair na Vatac\u00e1ine" },
+            { "timezone.excity.Europe/Vatican", "an Vatac\u00e1in" },
             { "timezone.excity.Europe/Vilnius", "Vilnias" },
             { "timezone.excity.Indian/Mayotte", "Mayotte" },
             { "timezone.excity.Indian/Reunion", "La R\u00e9union" },
-            { "timezone.excity.Pacific/Easter", "Oile\u00e1n na C\u00e1sca" },
             { "timezone.excity.Pacific/Kosrae", "Kosrae" },
             { "timezone.excity.Pacific/Majuro", "Majuro" },
             { "timezone.excity.Pacific/Midway", "Oile\u00e1in Midway" },
@@ -1912,13 +1912,11 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Tahiti", "Taih\u00edt\u00ed" },
             { "timezone.excity.Pacific/Tarawa", "Tarawa" },
             { "timezone.excity.Pacific/Wallis", "Vail\u00eds" },
-            { "timezone.excity.Africa/Blantyre", "Baile an tSaoir" },
             { "timezone.excity.Africa/Djibouti", "Djibouti" },
-            { "timezone.excity.Africa/El_Aaiun", "El Aaiun" },
+            { "timezone.excity.Africa/El_Aaiun", "L\u00e1\u00faine" },
             { "timezone.excity.Africa/Freetown", "Freetown" },
             { "timezone.excity.Africa/Gaborone", "Gaborone" },
             { "timezone.excity.Africa/Khartoum", "Cart\u00fam" },
-            { "timezone.excity.Africa/Kinshasa", "Cinseasa" },
             { "timezone.excity.Africa/Monrovia", "Monrovia" },
             { "timezone.excity.Africa/Ndjamena", "Ndjamena" },
             { "timezone.excity.Africa/Sao_Tome", "S\u00e3o Tom\u00e9" },
@@ -1929,7 +1927,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "timezone.excity.America/Chicago", "Chicago" },
             { "timezone.excity.America/Cordoba", "C\u00f3rdoba" },
             { "timezone.excity.America/Creston", "Creston" },
-            { "timezone.excity.America/Curacao", "Cura\u00e7ao" },
+            { "timezone.excity.America/Curacao", "C\u00faras\u00f3" },
             { "timezone.excity.America/Detroit", "Detroit" },
             { "timezone.excity.America/Grenada", "Grean\u00e1da" },
             { "timezone.excity.America/Halifax", "Halifax" },
@@ -1972,18 +1970,16 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Bujumbura", "Bujumbura" },
             { "timezone.excity.Africa/Mogadishu", "Mogaidisi\u00fa" },
             { "timezone.excity.America/Anguilla", "Anga\u00edle" },
-            { "timezone.excity.America/Asuncion", "As\u00fainseon" },
+            { "timezone.excity.America/Asuncion", "Asunci\u00f3n" },
             { "timezone.excity.America/Barbados", "Barbad\u00f3s" },
             { "timezone.excity.America/Dominica", "Doiminice" },
             { "timezone.excity.America/Edmonton", "Edmonton" },
-            { "timezone.excity.America/Eirunepe", "Eirunep\u00e9" },
             { "timezone.excity.America/Mazatlan", "Mazatlan" },
             { "timezone.excity.America/Miquelon", "Miquelon" },
             { "timezone.excity.America/New_York", "Nua-Eabhrac" },
             { "timezone.excity.America/Resolute", "Resolute" },
-            { "timezone.excity.America/Santarem", "Santar\u00e9m" },
-            { "timezone.excity.America/Santiago", "Saintiag\u00f3" },
             { "timezone.excity.America/St_Kitts", "San Cr\u00edost\u00f3ir" },
+            { "timezone.excity.America/St_Lucia", "Saint Lucia" },
             { "timezone.excity.America/Winnipeg", "Winnipeg" },
             { "timezone.excity.Antarctica/Casey", "Casey" },
             { "timezone.excity.Antarctica/Davis", "Davis" },
@@ -2050,13 +2046,11 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Simferopol", "Simferopol" },
             { "timezone.excity.Europe/Zaporozhye", "Zaporozhye" },
             { "timezone.excity.Pacific/Enderbury", "Enderbury" },
-            { "timezone.excity.Pacific/Galapagos", "Gal\u00e1pagos" },
             { "timezone.excity.Pacific/Kwajalein", "Kwajalein" },
             { "timezone.excity.Pacific/Marquesas", "na hOile\u00e1in Mharcasacha" },
             { "timezone.excity.Pacific/Pago_Pago", "Pago Pago" },
             { "timezone.excity.Pacific/Rarotonga", "Rarotonga" },
             { "timezone.excity.Pacific/Tongatapu", "Tongatapu" },
-            { "timezone.excity.Africa/Addis_Ababa", "Adas Ababa" },
             { "timezone.excity.Africa/Brazzaville", "Brazzaville" },
             { "timezone.excity.Africa/Ouagadougou", "Ouagadougou" },
             { "timezone.excity.America/Costa_Rica", "C\u00f3sta R\u00edce" },
@@ -2092,7 +2086,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "timezone.excity.America/Mexico_City", "Cathair Mheicsiceo" },
             { "timezone.excity.America/Pangnirtung", "Pangnirtung" },
             { "timezone.excity.America/Porto_Velho", "Porto Velho" },
-            { "timezone.excity.America/Puerto_Rico", "Port\u00f3 R\u00edce" },
+            { "timezone.excity.America/Puerto_Rico", "P\u00f3rt\u00f3 R\u00edce" },
             { "timezone.excity.America/Rainy_River", "Rainy River" },
             { "timezone.excity.America/Tegucigalpa", "Tegucigalpa" },
             { "timezone.excity.America/Thunder_Bay", "Thunder Bay" },
